@@ -5,7 +5,6 @@ import nats
 import logging
 
 from nats.aio.client import Client as NATS
-from nats.js.client import JetStream
 
 from typing import Callable, Dict, Optional, List
 from pydantic import BaseModel
@@ -15,7 +14,6 @@ class JetStreamMessagingBot(BaseModel):
     botname: str
     nats_url: str
     nc: Optional[NATS]
-    js: Optional[JetStream]
 
     class Config:
         arbitrary_types_allowed = True
