@@ -4,10 +4,10 @@ import nats
 import logging
 
 from pydantic import BaseModel
-from typing import Optional
+from typing import Callable, Optional
 
 from nats.aio.client import Client as NATS
-from stan.aio.client import Client as STAN
+from stan.aio.client import DEFAULT_ACK_WAIT, DEFAULT_MAX_INFLIGHT, DEFAULT_MAX_PUB_ACKS_INFLIGHT, Client as STAN
 
 logging.basicConfig(level=logging.DEBUG,
                     format="%(levelname)s:%(asctime)s:%(message)s")
@@ -25,7 +25,16 @@ class MessagingBot(BaseModel):
     class Config:
         arbitrary_types_allowed = True
 
-    async def connect_nats_streaming(self):
+    async def cb_ack(self, message):
+        logging.info(f"Recived ack: {message.guid}")
+
+    async def cb_error(self, message):
+        logging.error(f"Encountered error: {message}")
+
+    async def cb_conn_lost(self, message):
+        logging.error(f"Connection Lost: {message}")
+
+    async def connect_nats_streaming(self, max_pub_acks_inflight=DEFAULT_MAX_PUB_ACKS_INFLIGHT):
         logging.info("Connecting Bot to NATS Streaming")
         try:
             # random_number = random.randint(0, 1000)
@@ -36,28 +45,31 @@ class MessagingBot(BaseModel):
                 cluster_id=self.stan_cluster_id,
                 client_id=f"{self.stan_client_id}_{self.pod_name}",
                 nats=self.nc,
+                max_pub_acks_inflight=max_pub_acks_inflight,
+                conn_lost_cb=self.cb_conn_lost
+
             )
             logging.info("NATS Streaming Connected")
         except Exception as err:
             logging.debug(f"Could not conenct to NATS")
             logging.error(err)
 
-    async def cb_ack(self, message):
-        logging.info(f"Recived ack: {message.guid}")
-
-    async def subscribe(self, subject, durable_name=None, cb=None, start_at=None):
+    async def subscribe(self, subject: str, durable_name: str = None, cb: Callable = None, start_at: str = None, max_inflight: int = DEFAULT_MAX_INFLIGHT, ack_wait: int = DEFAULT_ACK_WAIT):
         sc = self.sc
         await sc.subscribe(
             subject=subject,
             durable_name=durable_name,
             cb=cb,
+            error_cb=self.cb_error,
             manual_acks=True,
             start_at=start_at,
+            ack_wait=ack_wait,
+            max_inflight=max_inflight
         )
 
-    async def publish(self, subject, payload):
+    async def publish(self, subject: str, payload: bytes, ack_wait=DEFAULT_ACK_WAIT):
         sc = self.sc
-        await sc.publish(subject=subject, payload=payload, ack_handler=self.cb_ack)
+        await sc.publish(subject=subject, payload=payload, ack_handler=self.cb_ack, ack_wait=ack_wait)
 
     async def close(self):
         await self.sc.close()
